@@ -3,7 +3,7 @@ package VCS::CMSynergy;
 # Copyright (c) 2001-2015 argumentum GmbH
 # See COPYRIGHT section in VCS/CMSynergy.pod for usage and distribution rights.
 
-our $VERSION = '1.48';
+our $VERSION = '1.49';
 
 use 5.008_001;                          # i.e. v5.8.1
 use strict;
@@ -1364,7 +1364,8 @@ sub project_tree
 
     my $mark_projects = delete $wanted{mark_projects};
     $wanted{pathsep} ||= VCS::CMSynergy::Client::_pathsep;
-    my $omit_rx = (delete $wanted{omit_top_dir}) && qr/^.*?\Q$wanted{pathsep}\E/;
+    my $omit_rx = (delete $wanted{omit_top_dir}) 
+                  && qr/^.*?\Q$wanted{pathsep}\E/; # everything up to the first pathsep
     # NOTE: all other options are passed thru to traverse() 
     # (and get checked there)
 
@@ -1380,7 +1381,10 @@ sub project_tree
         # directory; the "||=" below makes sure we dont't overwrite
         # the project entry when "mark_projects" is in effect
         my $path = VCS::CMSynergy::Traversal::path();
-        $path =~ s/$omit_rx// or next if $omit_rx;
+        if ($omit_rx)
+        {
+            $path =~ s/$omit_rx// or return; # drop top level entirely
+        }
         @$projects == 1 ? $tree{$path} : $tree{$path}->[$idx] ||= $_;
     };
 
@@ -1466,7 +1470,7 @@ sub get_attribute
 
     my ($rc, $out, $err) = $self->_ccm(qw/attribute -show/, $name, $file_spec);
     return $out if $rc == 0;
-    return if ($err || $out) =~ /Attribute .* does not exist on object/;
+    return if ($err || $out) =~ /Attribute .* does not exist/;
     return $self->set_error($err || $out);
 }
 
