@@ -73,9 +73,11 @@ use overload
 my $have_weaken = eval "use Scalar::Util qw(weaken); 1";
 
 
-my %cvtype2subclass = 
-( 
-    project	=> "Project",
+my %cvtype2subclass = qw(
+    baseline          Baseline
+    project	      Project
+    project_grouping  ProjectGrouping
+    process_rule      ProcessRule
 );
 
 # no need to cache these attributes
@@ -359,13 +361,62 @@ sub AUTOLOAD
     croak("Can't locate class method \"$method\" via class \"$class\"")
 	unless ref $this;
 
-    if ($method =~ /^(is_.*_of|has_.*)$/)
+    if ($method =~ /^(?:is_.*_of|has_.*)$/)
     {
 	return $this->ccm->query_object("$method('$this')", @_);
     }
     croak("Can't locate object method \"$method\" via class \"$class\"");
 }
 
+# this method requires $self to implement a method _show($what, \@keywords, $row_type)
+sub show_hashref
+{
+    my $self = shift;
+    my ($what, $keywords) = validate(\@_, Str, VCS::CMSynergy::_KEYWORDS());
+    return $self->_show($what, $keywords, VCS::CMSynergy::ROW_HASH());
+}
+
+# this method requires $self to implement a method _show($what, \@keywords, $row_type)
+sub show_object
+{
+    my $self = shift;
+    my ($what, $keywords) = validate(\@_, Str, VCS::CMSynergy::_KEYWORDS());
+    return $self->_show($what, $keywords, VCS::CMSynergy::ROW_OBJECT());
+}
+
+# helper method use by several _show() implementations
+sub _generic_show
+{
+    my ($self, $cmd, $valid_whats, $what, $keywords, $row_type) = @_;
+
+    croak(__PACKAGE__.'::show_{hashref,object} are only available in web mode')
+        unless $self->ccm->web_mode;
+    croak(__PACKAGE__.'::show_{hashref,object}($what, ...): $what must be one of '
+         .join(", ", @$valid_whats))
+        unless grep { $_ eq $what } @$valid_whats; 
+
+    my $want = VCS::CMSynergy::_want($row_type, $keywords);
+    my $format = $VCS::CMSynergy::RS . join($VCS::CMSynergy::FS, values %$want) . $VCS::CMSynergy::FS;
+
+    my ($rc, $out, $err) = $self->ccm->ccm( 
+            $cmd, qw/-u -ns -nch -nf/,
+            -show   => $what,
+            -format => $format, $self);
+    return $self->set_error($err || $out) unless $rc == 0;
+
+    # split $out at $RS and ignore the first element
+    # (which is either empty or a header like "Baseline...:")
+    my (undef, @records) = split(/\Q${VCS::CMSynergy::RS}\E/, $out);
+
+    my @result;
+    foreach (@records)
+    {
+        my @cols = split(/\Q${VCS::CMSynergy::FS}\E/, $_, -1);    # don't strip empty trailing fields
+        my $row = $self->ccm->_query_result($want, \@cols, $row_type);
+        push @result, $row;
+    }
+    return \@result;
+}
 
 1;
 
@@ -380,7 +431,7 @@ method (see below), it can be used with C<VCS::CMSynergy> methods wherever
 an objectname would be appropriate, esp. where the documentation
 specifies a B<file_spec>.
 
-When L<VCS::CMSynergy::Object/:cached_attributes> is in effect,
+When L<VCS::CMSynergy/:cached_attributes> is in effect,
 a C<VCS::CMSynergy::Object> keeps a "demand loaded"
 cache of attribute names and values.
 
