@@ -417,138 +417,6 @@ sub _traverse
     return 1;
 }
 
-
-=head2 get_member_info_hashref, get_member_info_object
-
-NOTE: This methods are only useful if you have the optional
-Synergy command B<get_member_info> (from the "PC Integrations" package)
-installed, cf. F<README.get_member_info> for details.
-
-  $members1 = $proj->get_member_info_hashref(@keywords, \%options);
-  $members2 = $proj->get_member_info_object(@keywords, \%options);
- 
-  while (my ($path, $member) = each %$members2) 
-  {
-    print "$path $member\n";
-  }
-
-C<get_member_info_hashref> and C<get_member_info_object>
-execute B<ccm get_member_info> to obtain the members of project C<$proj>.
-They both return a reference to a hash where the keys are the 
-workarea (relative) pathnames of the members. For C<get_member_info_hashref>,
-the value is a hash of attributes similar to L<VCS::CMSynergy/query_hashref>.
-For C<get_member_info_object>, the value is the member itself
-(a L<CVS::CMSYnergy::Object>), similar to  L<VCS::CMSynergy/query_object>.
-
-If there was an error, C<undef> is returned.
-
-See the description of  L<VCS::CMSynergy/query_hashref> or 
-L<VCS::CMSynergy/query_object>, resp., for the meaning of
-C<@keywords>. Both methods also accept an optional trailing  
-hash reference. Possible keys are:
-
-=over 4
-
-=item C<subprojects> (boolean)
-
-whether to list members of sub projects (recursively), default: false
-
-=item C<pathsep> (string)
-
-separator to use for the workarea pathnames, default: the platform's
-native path separator
-
-=back 
-
-Note the following deficiencies inherited from B<ccm get_member_info>:
-
-=over 4
-
-=item *
-
-The member hash does not contain any directories (i.e. Synergy objects
-with cvtype "dir"). This usually not a problem since (1) directories
-don't carry much information relevant to version control and (2) their
-existence is easily inferred from the pathnames. But information
-about empty directories will be lost.
-
-=item *
-
-If option C<subprojects> is true the member hash contains 
-all members of all sub projects, but doesn't give any information
-which sub project a certain member belongs to.
-
-=back
-
-Note the following differences from B<ccm get_member_info>:
-
-=over 4
-
-=item *
-
-Workarea pathnames are always relative (to the top of the workarea),
-irrespective whether C<$proj> currently maintains a workarea or not.
-
-=back
-
-=cut
-
-sub get_member_info_hashref
-{
-    my $self = shift;
-    my $opts = @_ && ref $_[-1] eq "HASH" ? pop : {};
-    return $self->_get_member_info(\@_, $opts, 0);
-}
-
-sub get_member_info_object
-{
-    my $self = shift;
-    my $opts = @_ && ref $_[-1] eq "HASH" ? pop : {};
-    return $self->_get_member_info(\@_, $opts, 1);
-}
-
-# private method: wrapper for get_member_info from PC integrations intlib.a
-# if $row_object is true, returns objects, otherwise hashes
-sub _get_member_info
-{
-    my ($self, $keywords, $opts, $want_row_object) = @_;
-
-    my $want = VCS::CMSynergy::_want($want_row_object, $keywords);
-
-    # NOTE: $RS is at the end (because get_member_info _prepends_ the path)
-    my $format = $VCS::CMSynergy::FS . join($VCS::CMSynergy::FS, values %$want) . $VCS::CMSynergy::RS;	
-
-    my @cmd =  qw/get_member_info/;
-    push @cmd, "-recurse" if $opts->{subprojects};
-
-    my ($rc, $out, $err) = $self->ccm->_ccm(@cmd, -format => $format, $self);
-    return $self->ccm->set_error($err || $out) unless $rc == 0;
-
-    my %result;
-    my $wa_path_len = 
-	$self->get_attribute("maintain_wa") eq "TRUE" ?
-	    length($self->get_attribute("wa_path")) + 1 : 0;
-
-    my $_pathsep = VCS::CMSynergy::Client::_pathsep;
-
-    # split into records
-    # NOTE: $RS is followed by \n
-    foreach (split(/\Q${VCS::CMSynergy::RS}\E\s*/, $out))		
-    {
-	my @cols = split(/\Q${VCS::CMSynergy::FS}\E/, $_, -1);
-
-	# path information is the first "column", strip wa_path if necessary
-	my $path = shift @cols;	
-	substr($path, 0, $wa_path_len) = "" if $wa_path_len;
-	$path =~ s/\Q$_pathsep\E/$opts->{pathsep}/g if $opts->{pathsep};
-
-	$result{$path} = $self->ccm->_parse_query_result($want, \@cols, $want_row_object);
-    }
-
-    return \%result;
-}
-
-
 =head1 CONVENIENCE METHODS
 
 =head2 recursive_is_member_of, hierarchy_project_members
